## 4.2.2.1 (2022-10-23)

Remove tzlocal from pyright's exclude (#8969)

## 4.2.2 (2022-07-20)

Allowlist useless modules (#8340)

These are the ones I chose not to add from #8321

Fixes most of #8339

## 4.2.1 (2022-07-19)

Add missing third party modules (#8321)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: hauntsaninja <>
Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

## 4.2.0 (2022-06-26)

[stubsabot] Bump tzlocal to 4.2 (#8184)

Co-authored-by: hauntsaninja <>

## 4.1.1 (2022-06-26)

Check missing definitions for several packages (#8167)

Co-authored-by: hauntsaninja <>

## 4.1.0 (2022-01-14)

Add get_localzone_name to tzlocal (#6912)

## 3.0.0 (2021-10-12)

Update remaining versions for third-party stubs (#6094)

Also remove the python2 markers of packages that don't list Python 2
as supported in the latest version.

Don't special case version '0.1'

Co-authored-by: Akuli <akuviljanen17@gmail.com>

